# -*- coding: utf-8 -*-

"""Top-level package for Clockify API Python client."""

__author__ = """Sjoerd Kerkstra"""
__email__ = "sjoerdk1@xs4all.nl"
__version__ = "0.2.2"
